API Reference
=============

This page lists all the modules available in the API.

.. toctree::
   :maxdepth: 3
   :glob:

   api/tslumen
   api/tslumen.profile
   api/tslumen.report
   api/tslumen.plot
   api/tslumen.cli
   api/tslumen.scheduling
   api/tslumen.misc
   api/tslumen.jinja_utils



See also the :doc:`complete index of functions and classes<genindex>`.
